@@ -33,9 +33,10 @@ class FileDescriptorSetGenerator(abc.ABC):
         fdset = FileDescriptorSet.FromString(self.generate_file_descriptor_set_bytes())
 
         for fd in fdset.file:
+            fd_name = _PROTO_SUFFIX_PATTERN.sub(r"\1", fd.name)
             for dep in fd.dependency:
                 register_import_rewrite(
-                    build_import_rewrite(_PROTO_SUFFIX_PATTERN.sub(r"\1", dep))
+                    build_import_rewrite(fd_name, _PROTO_SUFFIX_PATTERN.sub(r"\1", dep))
                 )
 
         rewriter = ImportRewriter()
@@ -53,6 +54,11 @@ class FileDescriptorSetGenerator(abc.ABC):
         if create_init:
             generated_python_dir.joinpath("__init__.py").touch(exist_ok=True)
 
+            # recursively create packages
+            for dir_entry in generated_python_dir.rglob("*"):
+                if dir_entry.is_dir():
+                    dir_entry.joinpath("__init__.py").touch(exist_ok=True)
+
 
 class Protoc(FileDescriptorSetGenerator):
     def __init__(
@@ -91,6 +97,7 @@ class Buf(FileDescriptorSetGenerator):
                 self.fdset_generator_binary,
                 "build",
                 "--as-file-descriptor-set",
+                "--exclude-source-info",
                 "--output",
                 "-",
             ]
